import os
import sys
import shlex
import click


# CREDIT: https://gist.github.com/bortzmeyer/1284249#gistcomment-3074036
def create_ssh(ip: str, port: str, user: str, debug: bool, cd_folder: str = None, shell: str = 'bash'):
    """Create a ssh session"""

    ssh = f'/usr/bin/ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=ERROR -p {port} {user}@{ip}'
    if cd_folder:
        ssh = ssh + f' -t "cd {cd_folder}; {shell} --login"'

    pid = os.fork()
    if pid == 0:  # a child process
        if debug: 
            print(f"{ssh}")
        cmd = shlex.split(ssh)
        os.execv(cmd[0], cmd)

    os.wait()


def do_scp(ip: str, port: str, user: str, src: str, target: str, show: bool, debug: bool):
    """Create a ssh session"""

    scp = f'/usr/bin/scp -P {port} -r -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=ERROR {src} {user}@{ip}:{target}'
    if show:
        print(scp)
        return

    pid = os.fork()
    if pid == 0:  # a child process
        if debug: 
            print(f"{scp}")
        cmd = shlex.split(scp)
        os.execv(cmd[0], cmd)

    os.wait()


import configparser


def read(file_path, debug=False):
    data = {}
    envs = {}

    config = configparser.ConfigParser()
    config.read(file_path)
    section = config.sections()[0]
    for key in config[section]:
        val = config[section][key]
        if key.startswith('env.'):
            key = key.replace('env.', '')
            envs[key.upper()] = val
        else:
            data[key] = val

    data['envs'] = envs
    if debug:
        print(data)

    return data



import os
from vag.utils.nomadutil import get_ip_port
import click
import sys
import requests
from vag.utils.misc import create_ssh

@click.group()
def coder():
    """ Coder automation """
    pass


@coder.command()
@click.option('--debug', is_flag=True, default=False, help='debug this command')
def ssh(debug: bool):
    """SSH into codeserver"""
    ip, port = get_ip_port('codeserver', debug)
    if debug:
        print(f'ip = {ip}, port = {port}')

    create_ssh(ip, port, 'coder', debug, '/home/coder/workspace', 'zsh')


import requests
import os
import sys

def get_ip_port(job_name: str, debug: bool):
    alloc = get_allocation(job_name, debug)

    ip = alloc['Resources']['Networks'][0]['IP']
    dynamic_ports = alloc['Resources']['Networks'][0]['DynamicPorts']
    port = ''
    for p in dynamic_ports:
        if p['Label'] == 'ssh':
            port = p['Value']
            break
    
    return ip, port


def get_version(job_name: str, debug: bool):
    alloc = get_allocation(job_name, debug)

    image = alloc['Job']['TaskGroups'][0]['Tasks'][0]['Config']['image']
    if debug:
        print(image)
    version = image[image.rfind(':')+1:]
    return version


def get_allocation(job_name: str, debug: bool):
    nomad_addr = os.getenv('NOMAD_ADDR')
    if not nomad_addr:
        print('missing $NOMAD_ADDR environment variable')
        sys.exit(1)

    allocations_api_url = f'{nomad_addr}/v1/job/{job_name}/allocations'
    if debug:
        print(allocations_api_url)
        
    allocations = requests.get(allocations_api_url).json()
    if debug:
        print(allocations)

    alloc_id = ''
    for a in allocations:
        if a['TaskStates'][f'{job_name}-service']['State'] == 'running':
            alloc_id = a['ID']

    if debug:
        print(f'alloc_id = {alloc_id}')

    alloc = requests.get(f'{nomad_addr}/v1/allocation/{alloc_id}').json()
    if debug:
        print(alloc)    
    return alloc

# /Job/TaskGroups[0]/Tasks[0]/Config/image


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vag', 'vag.console', 'vag.console.commands', 'vag.utils']

package_data = \
{'': ['*'], 'vag': ['scripts/*', 'scripts/build/*', 'scripts/instance/*']}

install_requires = \
['Click>=7.1.2,<8.0.0',
 'jinja2>=2.11.2,<3.0.0',
 'requests>=2.25.1,<3.0.0',
 'untangle>=1.1.1,<2.0.0']

entry_points = \
{'console_scripts': ['vag = vag.console.application:main']}

setup_kwargs = {
    'name': 'vag',
    'version': '0.1.35',
    'description': 'vagrant utility cli tool',
    'long_description': '# vag\nvag is a command line utility tool for vagrant, docker and [builder](https://github.com/7onetella/containers/tree/master/builder)\n\n## Documentation\n[read the docs](https://vag.readthedocs.io/en/latest/index.html)\n\n## Installation\n```bash\n$ pip install vag\n```\n\n## List of top level commands\n```bash\n$ vag\nUsage: vag [OPTIONS] COMMAND [ARGS]...\n\nOptions:\n  --help  Show this message and exit.\n\nCommands:\n  build     Builds vagrant box\n  clean     Cleans up vagrant build, terminates vagrant instance etc\n  docker    Docker automation\n  init      Creates a new Vagrantfile\n  instance  Vagrant Instance Automation\n  push      Publishes vagrant box to target environment\n  ssh       SSH to vagrant test Vagrant instance\n  test      Start a test Vagrant instance\n  version   Prints version\n```\n\n## Development\nlocal vag installation\n```bash\n$ rm -rf dist/*\n$ poetry install\n$ poetry build\n$ pip uninstall -y vag\n$ pip install dist/*.whl\n```\n\nedit and run \n```bash\n$ poetry run vag vagrant list\n```\n\n',
    'author': 'Seven Tella',
    'author_email': '7onetella@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
